@@ -1,4 +1,4 @@
 # SPDX-FileCopyrightText: 2022-present Darren Haba <darrenhaba@live.com>
 #
 # SPDX-License-Identifier: MIT
-from .privateprefs import load, load_dict, delete, delete_all
+from .privateprefs import load, load_keys, delete, delete_all
